package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallAcceptRateSetting;
import org.apache.ibatis.annotations.Param;

/**
 * 录取率范围设定Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-26
 */
public interface MallAcceptRateSettingMapper
{
    /**
     * 查询录取率范围设定
     *
     * @param rateMatchId 录取率范围设定主键
     * @return 录取率范围设定
     */
    public MallAcceptRateSetting selectMallAcceptRateSettingByRateMatchId(Long rateMatchId);

    /**
     * 录取设定
     * @return
     */
    public List<MallAcceptRateSetting> selectRateSettingList();

    /**
     * 查询录取率范围设定列表
     *
     * @param mallAcceptRateSetting 录取率范围设定
     * @return 录取率范围设定集合
     */
    public List<MallAcceptRateSetting> selectMallAcceptRateSettingList(MallAcceptRateSetting mallAcceptRateSetting);

    /**
     * 新增录取率范围设定
     *
     * @param mallAcceptRateSetting 录取率范围设定
     * @return 结果
     */
    public int insertMallAcceptRateSetting(MallAcceptRateSetting mallAcceptRateSetting);

    /**
     * 修改录取率范围设定
     *
     * @param mallAcceptRateSetting 录取率范围设定
     * @return 结果
     */
    public int updateMallAcceptRateSetting(MallAcceptRateSetting mallAcceptRateSetting);

    /**
     * 删除录取率范围设定
     *
     * @param rateMatchId 录取率范围设定主键
     * @return 结果
     */
    public int deleteMallAcceptRateSettingByRateMatchId(Long rateMatchId);

    /**
     * 批量删除录取率范围设定
     *
     * @param rateMatchIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallAcceptRateSettingByRateMatchIds(Long[] rateMatchIds);
}
